@@ -886,8 +886,8 @@ extern short *allocselect(void);
 extern void setoptionmenu(void);
 extern int test_insideness(int, int, XPoint *);
 extern Boolean pathselect(genericptr *, short, float);
-extern Boolean areaelement(genericptr *, Boolean, short);
-extern Boolean selectarea(objectptr, short);
+extern Boolean areaelement(genericptr *, XPoint *, Boolean, short);
+extern Boolean selectarea(objectptr, XPoint *, short);
 extern void startdesel(xcWidget, caddr_t, caddr_t);
 extern void deselect(xcWidget, caddr_t, caddr_t);
 extern void draw_normal_selected(objectptr, objinstptr);
