@@ -836,7 +836,7 @@ selection *genselectelement(short class, u_char mode, objectptr selobj,
 /* select arc, curve, and polygon objects from a defined box area */
 /*----------------------------------------------------------------*/
 
-Boolean areaelement(genericptr *curgen, Boolean is_path, short level)
+Boolean areaelement(genericptr *curgen, XPoint *boxpts, Boolean is_path, short level)
 {
    Boolean selected;
    pointlist    currentpt;
@@ -847,10 +847,8 @@ Boolean areaelement(genericptr *curgen, Boolean is_path, short level)
       case(ARC):
 	   /* check center of arcs */
 
-      	   selected = (TOARC(curgen)->position.x < areawin->save.x) &&
-	  	(TOARC(curgen)->position.x > areawin->origin.x) &&
-		(TOARC(curgen)->position.y < areawin->save.y) &&
-		(TOARC(curgen)->position.y > areawin->origin.y);
+	   selected = test_insideness(TOARC(curgen)->position.x,
+		TOARC(curgen)->position.x, boxpts);
 	   break;
 
       case(POLYGON):
@@ -861,9 +859,7 @@ Boolean areaelement(genericptr *curgen, Boolean is_path, short level)
            for (currentpt = TOPOLY(curgen)->points; currentpt <
 		TOPOLY(curgen)->points + TOPOLY(curgen)->number;
 		currentpt++, cycle++) {
-              if ((currentpt->x < areawin->save.x) && (currentpt->x >
-	           areawin->origin.x) && (currentpt->y < areawin->save.y) &&
-	           (currentpt->y > areawin->origin.y)) {
+	      if (test_insideness(currentpt->x, currentpt->y, boxpts)) {
 	         selected = True;
 		 if (level == 0) addcycle(curgen, cycle, 0);
 	      }
@@ -874,18 +870,14 @@ Boolean areaelement(genericptr *curgen, Boolean is_path, short level)
 	   /* check each control point of the spline */
 	
 	   selected = False;
-           if ((TOSPLINE(curgen)->ctrl[0].x < areawin->save.x) && 
-	   	(TOSPLINE(curgen)->ctrl[0].x > areawin->origin.x) &&
-		(TOSPLINE(curgen)->ctrl[0].y < areawin->save.y) &&
-		(TOSPLINE(curgen)->ctrl[0].y > areawin->origin.y)) {
+	   if (test_insideness(TOSPLINE(curgen)->ctrl[0].x,
+			TOSPLINE(curgen)->ctrl[0].y, boxpts)) {
 	      selected = True;
 	      if (level == 0) addcycle(curgen, 0, 0);
 	   }
 
-	   if ((TOSPLINE(curgen)->ctrl[3].x < areawin->save.x) &&
-		(TOSPLINE(curgen)->ctrl[3].x > areawin->origin.x) &&
-		(TOSPLINE(curgen)->ctrl[3].y < areawin->save.y) &&
-		(TOSPLINE(curgen)->ctrl[3].y > areawin->origin.y)) {
+	   if (test_insideness(TOSPLINE(curgen)->ctrl[3].x,
+			TOSPLINE(curgen)->ctrl[3].y, boxpts)) {
 	      selected = True;
 	      if (level == 0) addcycle(curgen, 3, 0);
 	   }
@@ -898,7 +890,7 @@ Boolean areaelement(genericptr *curgen, Boolean is_path, short level)
 /* select all objects from a defined box area */
 /*--------------------------------------------*/
 
-Boolean selectarea(objectptr selobj, short level)
+Boolean selectarea(objectptr selobj, XPoint *boxpts, short level)
 {
    short	*newselect;
    genericptr   *curgen, *pathgen;
@@ -906,22 +898,8 @@ Boolean selectarea(objectptr selobj, short level)
    stringpart	*strptr;
    int		locpos, cx, cy, hwidth, hheight;
    objinstptr	curinst;
-   XPoint	saveorig, savesave, tmppt;
+   XPoint	newboxpts[4];
 
-   /* put points of area bounding box into proper order */
-
-   if (areawin->origin.y > areawin->save.y) {
-      short tmp;
-      tmp = areawin->origin.y;
-      areawin->origin.y = areawin->save.y;
-      areawin->save.y = tmp;
-   }
-   if (areawin->origin.x > areawin->save.x) {
-      short tmp;
-      tmp = areawin->origin.x;
-      areawin->origin.x = areawin->save.x;
-      areawin->save.x = tmp;
-   }
    if (selobj == topobject) {
       areawin->textpos = areawin->textend = 0;
    } 
@@ -937,40 +915,20 @@ Boolean selectarea(objectptr selobj, short level)
 
 	    /* An object instance is selected if any part of it is	*/
 	    /* selected on a recursive area search.			*/
-            savesave.x = areawin->save.x;
-            savesave.y = areawin->save.y;
-            saveorig.x = areawin->origin.x;
-            saveorig.y = areawin->origin.y;
 
-	    areawin->save.x = (areawin->origin.x + areawin->save.x) / 2;
-	    areawin->save.y = (areawin->origin.y + areawin->save.y) / 2;
-
-            InvTransformPoints(&areawin->save, &tmppt, 1, curinst->position,
+            InvTransformPoints(boxpts, newboxpts, 4, curinst->position,
 			curinst->scale, curinst->rotation);
-	    hwidth = (savesave.x - saveorig.x) / (2 * curinst->scale);
-	    hheight = (savesave.y - saveorig.y) / (2 * curinst->scale);
-            areawin->save.x = tmppt.x + hwidth;
-            areawin->save.y = tmppt.y + hheight;
-            areawin->origin.x = tmppt.x - hwidth;
-            areawin->origin.y = tmppt.y - hheight;
-
-            selected = selectarea(curinst->thisobject, level + 1);
-            areawin->save.x = savesave.x;
-            areawin->save.y = savesave.y;
-            areawin->origin.x = saveorig.x;
-            areawin->origin.y = saveorig.y;
+            selected = selectarea(curinst->thisobject, newboxpts, level + 1);
 	    break;
 
 	case(GRAPHIC):
            /* check for graphic image center point inside area box */
-           selected = (TOGRAPHIC(curgen)->position.x < areawin->save.x) &&
-		(TOGRAPHIC(curgen)->position.x > areawin->origin.x) &&
-		(TOGRAPHIC(curgen)->position.y < areawin->save.y) &&
-		(TOGRAPHIC(curgen)->position.y > areawin->origin.y);
+	   selected = test_insideness(TOGRAPHIC(curgen)->position.x,
+		TOGRAPHIC(curgen)->position.x, boxpts);
 	   break;
 
         case(LABEL): {
-	   XPoint bboxpts[4], newboxpts[4], adj;
+	   XPoint adj;
 	   labelptr slab = TOLABEL(curgen);
 	   short j, state, isect, tmpl1, tmpl2;
 	   TextExtents tmpext;
@@ -983,14 +941,8 @@ Boolean selectarea(objectptr selobj, short level)
 	   /* Ignore info and pin labels that are not on the top level */
 	   if ((selobj != topobject) && (slab->pin != False)) break;
 
-	   /* create a 4-point polygon out of the select box information */
-	   bboxpts[0].x = bboxpts[3].x = areawin->origin.x;
-	   bboxpts[0].y = bboxpts[1].y = areawin->origin.y;
-	   bboxpts[1].x = bboxpts[2].x = areawin->save.x;
-	   bboxpts[2].y = bboxpts[3].y = areawin->save.y;
-
    	   /* translate select box into the coordinate system of the label */
-	   InvTransformPoints(bboxpts, newboxpts, 4, slab->position,
+	   InvTransformPoints(boxpts, newboxpts, 4, slab->position,
 		  slab->scale, slab->rotation);
 
 	   if (slab->pin) {
@@ -1047,12 +999,12 @@ Boolean selectarea(objectptr selobj, short level)
 	   selected = False;
 	   for (pathgen = TOPATH(curgen)->plist; pathgen < TOPATH(curgen)->plist
 		  + TOPATH(curgen)->parts; pathgen++) {
-	      if (areaelement(pathgen, True, level)) selected = True;
+	      if (areaelement(pathgen, boxpts, True, level)) selected = True;
 	   }
 	   break;
 
 	default:
-	   selected = areaelement(curgen, False, level);
+	   selected = areaelement(curgen, boxpts, False, level);
 	   break;
       }
 
