@@ -422,6 +422,12 @@ enum loadmodes {IMPORT = 1, PSBKGROUND, SCRIPT, RECOVER,
 #define LIBRARY		3
 #define USERLIB		(xobjs.numlibs + LIBRARY - 1)
 
+/*----------------------------------------------------------------------*/
+/* Object instance styles						*/
+/*----------------------------------------------------------------------*/
+
+#define LINE_INVARIANT 1	/* Linewidth is invariant w.r.t. scale */
+
 /*----------------------------------------------------------------------*/
 /* Box styles								*/
 /*----------------------------------------------------------------------*/
@@ -681,6 +687,7 @@ typedef struct {
    u_short	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
+   u_short	style;
    XPoint	position;
    short	rotation;
    float	scale;
